from numpy import arange, sin, pi
import matplotlib
matplotlib.use('WXAgg')

from matplotlib.backends.backend_wxagg import FigureCanvasWxAgg as FigureCanvas
from matplotlib.backends.backend_wx import NavigationToolbar2Wx
from matplotlib.figure import Figure   # http://matplotlib.org/api/figure_api.html#module-matplotlib.figure

import wx

class CanvasPanel(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent)
        self.figure = Figure()
        self.axes = self.figure.add_subplot(111)
        self.canvas = FigureCanvas(self, -1, self.figure)        
        self.sizer = wx.BoxSizer(wx.VERTICAL)        
        self.sizer.Add(self.canvas, 1, wx.LEFT | wx.TOP | wx.GROW)        
        self.toolbar=NavigationToolbar2Wx(self.canvas)  # adds a figure toolbar        
        self.sizer.Add(self.toolbar, 0, wx.EXPAND)        
        self.SetSizer(self.sizer)        
        self.Fit()

    def draw(self):
        t = arange(0.0, 20, 0.05)
        y = sin(2 * pi * t)
        self.axes.plot(t, y)
        self.axes.set_title('y=sin(2 * pi * t)')
        self.axes.set_xlabel('t [sec]')
        self.axes.set_ylabel('y [/]')
        self.axes.grid()
        
 
if __name__ == "__main__":
    app = wx.PySimpleApp()
    fr = wx.Frame(None, title='test')
    panel = CanvasPanel(fr)
    panel.draw()
    fr.Show()
    app.MainLoop()
